# Changelog

## [0.3.0](https://github.com/Trunkate-AI/trunkate-ai-sdk/compare/python-v0.2.0...python-v0.3.0) (2026-03-17)


### Features

* Implement private data filtering ([05edc7f](https://github.com/Trunkate-AI/trunkate-ai-sdk/commit/05edc7f95233645c1fb66efc377cfc51aca03ca7))

## [0.2.0](https://github.com/Trunkate-AI/trunkate-ai-sdk/compare/python-v0.1.8...python-v0.2.0) (2026-03-03)


### Features

* implement percentage based bugeting ([d1d274f](https://github.com/Trunkate-AI/trunkate-ai-sdk/commit/d1d274f299e48b88ea28200bc8f8000ccb787655))

## [0.1.8](https://github.com/Trunkate-AI/trunkate-ai-sdk/compare/python-v0.1.7...python-v0.1.8) (2026-02-28)


### Bug Fixes

* change reduction_percent type to float across SDKs and fix cli response mapping ([8d8b1a9](https://github.com/Trunkate-AI/trunkate-ai-sdk/commit/8d8b1a9a469f5162928f206b476c010277f036b3))

## [0.1.7](https://github.com/Trunkate-AI/trunkate-ai-sdk/compare/python-v0.1.6...python-v0.1.7) (2026-02-28)


### Bug Fixes

* resolve node always-auth deprecation, cli bin path format, and cargo publish token deprecation ([0ad60d2](https://github.com/Trunkate-AI/trunkate-ai-sdk/commit/0ad60d2c6ada6e2dde985736a9637ec91ee9207f))

## [0.1.6](https://github.com/Trunkate-AI/trunkate-ai-sdk/compare/python-v0.1.5...python-v0.1.6) (2026-02-28)


### Bug Fixes

* enforce patch bumps to resolve registry publish failures ([925f2d5](https://github.com/Trunkate-AI/trunkate-ai-sdk/commit/925f2d5c38d1c61b21ebd59a4688d7e4cbd17568))

## [0.1.5](https://github.com/Trunkate-AI/trunkate-ai-sdk/compare/python-v0.1.4...python-v0.1.5) (2026-02-28)


### Documentation

* populate SDK readmes with official website documentation and fix release pipeline ([0029ca2](https://github.com/Trunkate-AI/trunkate-ai-sdk/commit/0029ca26022429f18ead88577c18f085bb689026))

## [0.1.4](https://github.com/Trunkate-AI/trunkate-ai-sdk/compare/python-v0.1.3...python-v0.1.4) (2026-02-28)


### Bug Fixes

* upgrade npm proxy to v11 and enforce full sdk release ([e764825](https://github.com/Trunkate-AI/trunkate-ai-sdk/commit/e7648257e9050e86cff15d38223c2458e7bbb69c))

## [0.1.3](https://github.com/Trunkate-AI/trunkate-ai-sdk/compare/python-v0.1.2...python-v0.1.3) (2026-02-28)


### Bug Fixes

* remove npm registry-url config to fix OIDC provenance and bump all SDKs ([5f93206](https://github.com/Trunkate-AI/trunkate-ai-sdk/commit/5f932067c98113dca6941d8ffbe2371834007335))
* resolve publish pipeline configuration bugs across sdks ([13d521f](https://github.com/Trunkate-AI/trunkate-ai-sdk/commit/13d521faf52138f4c00c8bc86c123fa269a65d1c))

## [0.1.2](https://github.com/Trunkate-AI/trunkate-ai-sdk/compare/v0.1.1...v0.1.2) (2026-02-28)


### Bug Fixes

* resolve publish pipeline configuration bugs across sdks ([13d521f](https://github.com/Trunkate-AI/trunkate-ai-sdk/commit/13d521faf52138f4c00c8bc86c123fa269a65d1c))

## [0.1.1](https://github.com/Trunkate-AI/trunkate-ai-sdk/compare/v0.1.0...v0.1.1) (2026-02-28)


### Bug Fixes

* remove npm registry-url config to fix OIDC provenance and bump all SDKs ([5f93206](https://github.com/Trunkate-AI/trunkate-ai-sdk/commit/5f932067c98113dca6941d8ffbe2371834007335))
